:root {
    --border-color: rgba(67, 76, 94, 1);
    --border-color-active: rgba(136, 192, 208, 1);

    --bg-color: rgba(30, 34, 42, 0.95);
    --bg-color-hover: rgba(46, 52, 64, 1);

    --border-radius: 12px;
    --border-size: 3px;
    --border-style: solid;

    --text-color: rgba(236, 239, 244, 1);

    --window-padding: 3px;
    --bg-window-color: rgba(36, 41, 53, 0.95);
}
