:root {
    --border-color: rgba(10, 27, 37, 0.5);
    --border-color-active: rgba(9, 92, 114, 0.9);

    --bg-color: rgba(0, 36, 45, 0.8);
    --bg-color-hover: rgba(7, 54, 66, 1);

    --border-radius: 12px;
    --border-size: 3px;
    --border-style: solid;

    --text-color: rgb(175, 189, 190);

    --window-padding: 2px;
    --bg-window-color: rgba(0, 43, 54, 0.85);
}
